Calculate Required Pipe Diameter using Flamant
Source:R/calc_diameter_flamant.R
calc_diameter_flamant.RdCalculates the required internal pipe diameter given a specific target head loss, length, flow rate, and Flamant roughness coefficient.
Arguments
- loss
Numeric. The target friction head loss (meters).
- length
Numeric. The length of the pipe (meters).
- flow
Numeric. The volumetric flow rate (cubic meters per second).
- coef
Numeric. The Flamant roughness coefficient (
b). Default is 0.000135, which is typical for smooth plastic pipes (e.g., PVC, PE).